//
//  ViewController.swift
//  Switch
//
//  Created by Mark Meretzky on 7/20/16.
//  Copyright © 2016 Mark Meretzky. All rights reserved.
//

import UIKit;
import AVFoundation; //for AVAudioPlayer

class ViewController: UIViewController {
	var player: AVAudioPlayer? = nil;

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;

		//Find the full pathname of the sound file musette.mp3.
		let bundle: NSBundle = NSBundle.mainBundle();
		let path: String? = bundle.pathForResource("musette", ofType: "mp3");
		if path == nil {
			print("could not find path to file musette.mp3");
			return;
		}
		print("path = \(path!)\n");

		//Store the full pathname into a url object.
		let url: NSURL? = NSURL(fileURLWithPath: path!, isDirectory: false);
		if url == nil {
			print("could not create URL");
			return;
		}
		print("url = \(url!)\n");

		//Create the audio player.
		do {
			try player = AVAudioPlayer(contentsOfURL: url!);
		} catch {
			print("could not create AVAudioPlayer: \(error)\n");
			return;
		}

		//Configure the audio player.
		player!.volume = 1.0;		//the default
		player!.numberOfLoops = -1;	//negative for infinite loop
		player!.pan = 0.0;			//-1.0 is left, +1.0 is right
		print("player!.numberOfChannels = \(player!.numberOfChannels)"); //mono or stereo

		if !player!.prepareToPlay() {	//means if player!.prepareToPlay() == false {
			print("player!.prepareToPlay failed");
		}
	}

	override func viewDidLoad() {
		super.viewDidLoad()
		// Do any additional setup after loading the view, typically from a nib.
	}
	
	func valueChanged(mySwitch: UISwitch!) {
		if player == nil {
			return;
		}

		if mySwitch.on {
			//The switch has just been turned on.
			if !player!.play() {
				print("player!.play failed.");
			}
			print("Playing at \(player!.currentTime) of \(player!.duration) seconds.");
		} else {
			//The switch has just been turned off.
			player!.pause();
			print("Paused at \(player!.currentTime) of \(player!.duration) seconds.");
			//Don't need to prepareToPlay again after a pause.
		}
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning()
		// Dispose of any resources that can be recreated.
	}


}

